@@ -1,28 +1,15 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "kdeapplicationtreelistwidget.h"
 #include "categorytypecombobox.h"
 #include "kdebugsettingsutil.h"
-#include <QHeaderView>
 #include <KLocalizedString>
+#include <QHeaderView>
 
 KDEApplicationTreeListWidgetItem::KDEApplicationTreeListWidgetItem(const QString &category, QTreeWidget *parent)
     : QTreeWidgetItem(parent)
@@ -94,7 +81,7 @@ QList<int> KDEApplicationTreeListWidget::searchColumns() const
 void KDEApplicationTreeListWidget::selectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        auto *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        auto itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         if (!itemWidget->isHidden()) {
             itemWidget->setType(LoggingCategory::Debug);
         }
@@ -104,7 +91,7 @@ void KDEApplicationTreeListWidget::selectAllDebugCategories()
 void KDEApplicationTreeListWidget::deSelectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        auto *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        auto itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         if (!itemWidget->isHidden()) {
             itemWidget->setType(LoggingCategory::Info);
         }
@@ -114,7 +101,7 @@ void KDEApplicationTreeListWidget::deSelectAllDebugCategories()
 void KDEApplicationTreeListWidget::deSelectAllMessagesCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        auto *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        auto itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         if (!itemWidget->isHidden()) {
             itemWidget->setType(LoggingCategory::Off);
         }
@@ -142,7 +129,7 @@ void KDEApplicationTreeListWidget::addListItems(const LoggingCategory::List &lis
         clear();
     }
     for (const LoggingCategory &cat : list) {
-        auto *item = new KDEApplicationTreeListWidgetItem(cat.categoryName, this);
+        auto item = new KDEApplicationTreeListWidgetItem(cat.categoryName, this);
         item->setToolTip(0, generateToolTip(cat));
         item->setText(KDEApplicationTreeListWidgetItem::Description, cat.description);
         item->setType(cat.loggingType);
@@ -162,7 +149,7 @@ LoggingCategory::List KDEApplicationTreeListWidget::rules(bool forceSavingAllRul
 {
     LoggingCategory::List lst;
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        auto *listWidgetItem = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        auto listWidgetItem = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         const LoggingCategory cat = listWidgetItem->rule(forceSavingAllRules);
         if (cat.isValid()) {
             lst.append(cat);
@@ -174,7 +161,7 @@ LoggingCategory::List KDEApplicationTreeListWidget::rules(bool forceSavingAllRul
 void KDEApplicationTreeListWidget::restoreToDefault()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        auto *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        auto itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         itemWidget->restoreToDefault();
     }
 }
