@@ -50,7 +50,7 @@ void LoadGroupMenu::init()
     }
     for (const QString &dirName : groupPath) {
         QDir dir(dirName);
-        mGroupNames = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+        mGroupNames += dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
         for (const QString &file : std::as_const(mGroupNames)) {
             QAction *act = addAction(file);
             const QString fullPath = dirName + QLatin1Char('/') + file;
